@@ -1,5 +1,5 @@
 /*
- * "$Id: dnssd.c 12818 2015-07-31 13:29:25Z msweet $"
+ * "$Id: dnssd.c 12967 2015-11-13 19:49:10Z msweet $"
  *
  * DNS-SD discovery backend for CUPS.
  *
@@ -921,13 +921,6 @@ get_device(cups_array_t *devices,	/* I - Device array */
   * Yes, add the device...
   */
 
-#ifdef HAVE_DNSSD
-  DNSServiceConstructFullName(fullName, serviceName, regtype, replyDomain);
-#else /* HAVE_AVAHI */
-  avahi_service_name_join(fullName, kDNSServiceMaxDomainName,
-			   serviceName, regtype, replyDomain);
-#endif /* HAVE_DNSSD */
-
   device           = calloc(sizeof(cups_device_t), 1);
   device->name     = strdup(serviceName);
   device->domain   = strdup(replyDomain);
@@ -943,8 +936,7 @@ get_device(cups_array_t *devices,	/* I - Device array */
 #ifdef HAVE_DNSSD
   DNSServiceConstructFullName(fullName, serviceName, regtype, replyDomain);
 #else /* HAVE_AVAHI */
-  avahi_service_name_join(fullName, kDNSServiceMaxDomainName,
-			   serviceName, regtype, replyDomain);
+  avahi_service_name_join(fullName, kDNSServiceMaxDomainName, serviceName, regtype, replyDomain);
 #endif /* HAVE_DNSSD */
 
   device->fullName = strdup(fullName);
@@ -1050,9 +1042,7 @@ query_callback(
                   "interfaceIndex=%d, errorCode=%d, fullName=\"%s\", "
 		  "rrtype=%u, rrclass=%u, rdlen=%u, rdata=%p, ttl=%u, "
 		  "context=%p)\n",
-          sdRef, flags, interfaceIndex, errorCode,
-	  fullName ? fullName : "(null)", rrtype, rrclass, rdlen, rdata, ttl,
-	  context);
+          sdRef, flags, interfaceIndex, errorCode, fullName, rrtype, rrclass, rdlen, rdata, ttl, context);
 
  /*
   * Only process "add" data...
@@ -1065,9 +1055,7 @@ query_callback(
   fprintf(stderr, "DEBUG2: query_callback(browser=%p, interfaceIndex=%d, "
                   "protocol=%d, event=%d, fullName=\"%s\", rrclass=%u, "
 		  "rrtype=%u, rdata=%p, rdlen=%u, flags=%x, context=%p)\n",
-          browser, interfaceIndex, protocol, event,
-	  fullName ? fullName : "(null)", rrclass, rrtype, rdata,
-	  (unsigned)rdlen, flags, context);
+          browser, interfaceIndex, protocol, event, fullName, rrclass, rrtype, rdata, (unsigned)rdlen, flags, context);
 
  /*
   * Only process "add" data...
@@ -1330,5 +1318,5 @@ unquote(char       *dst,		/* I - Destination buffer */
 
 
 /*
- * End of "$Id: dnssd.c 12818 2015-07-31 13:29:25Z msweet $".
+ * End of "$Id: dnssd.c 12967 2015-11-13 19:49:10Z msweet $".
  */
