@@ -1,5 +1,5 @@
 /*
- * "$Id: ipp-support.c 12194 2014-10-02 18:44:36Z msweet $"
+ * "$Id: ipp-support.c 12995 2015-11-20 02:32:42Z msweet $"
  *
  * Internet Printing Protocol support functions for CUPS.
  *
@@ -78,7 +78,8 @@ static const char * const ipp_status_oks[] =	/* "OK" status codes */
 		  "client-error-account-info-needed",
 		  "client-error-account-closed",
 		  "client-error-account-limit-reached",
-		  "client-error-account-authorization-failed"
+		  "client-error-account-authorization-failed",
+		  "client-error-not-fetchable"
 		},
 		* const ipp_status_480s[] =	/* Vendor client errors */
 		{
@@ -195,7 +196,7 @@ static const char * const ipp_std_ops[] =
 		  "Suspend-Current-Job",
 		  "Resume-Job",
 
-		  /* 0x0030 - 0x003e */
+		  /* 0x0030 - 0x003f */
 		  "Promote-Job",
 		  "Schedule-Job-After",
 		  "0x0032",
@@ -210,7 +211,21 @@ static const char * const ipp_std_ops[] =
 		  "Close-Job",
 		  "Identify-Printer",
 		  "Validate-Document",
-		  "Send-Hardcopy-Document"
+		  "Send-Hardcopy-Document",
+		  "Acknowledge-Document",
+
+		  /* 0x0040 - 0x004a */
+		  "Acknowledge-Identify-Printer",
+		  "Acknowledge-Job",
+		  "Fetch-Document",
+		  "Fetch-Job",
+		  "Get-Output-Device-Attributes",
+		  "Update-Active-Jobs",
+		  "Deregister-Output-Device",
+		  "Update-Document-Status",
+		  "Update-Job-Status",
+		  "Update-Output-Device-Attributes",
+		  "Get-Next-Document-Data"
 		},
 		* const ipp_cups_ops[] =
 		{
@@ -2271,5 +2286,5 @@ ipp_col_string(ipp_t  *col,		/* I - Collection attribute */
 
 
 /*
- * End of "$Id: ipp-support.c 12194 2014-10-02 18:44:36Z msweet $".
+ * End of "$Id: ipp-support.c 12995 2015-11-20 02:32:42Z msweet $".
  */
