@@ -1,5 +1,5 @@
 /*
- * "$Id: usersys.c 12817 2015-07-30 15:45:46Z msweet $"
+ * "$Id: usersys.c 12892 2015-10-08 17:24:57Z msweet $"
  *
  * User, system, and password routines for CUPS.
  *
@@ -1009,10 +1009,7 @@ cups_finalize_client_conf(
     * domain socket if it exists and has the right permissions...
     */
 
-    struct stat	sockinfo;		/* Domain socket information */
-
-    if (!stat(CUPS_DEFAULT_DOMAINSOCKET, &sockinfo) &&
-	(sockinfo.st_mode & (S_IROTH | S_IWOTH)) == (S_IROTH | S_IWOTH))
+    if (!access(CUPS_DEFAULT_DOMAINSOCKET, R_OK))
       cups_set_server_name(cc, CUPS_DEFAULT_DOMAINSOCKET);
     else
 #endif /* CUPS_DEFAULT_DOMAINSOCKET */
@@ -1285,5 +1282,5 @@ cups_set_user(
 
 
 /*
- * End of "$Id: usersys.c 12817 2015-07-30 15:45:46Z msweet $".
+ * End of "$Id: usersys.c 12892 2015-10-08 17:24:57Z msweet $".
  */
