@@ -1,5 +1,5 @@
 /*
- * "$Id: config.h 12831 2015-08-05 14:24:32Z msweet $"
+ * "$Id: config.h 12875 2015-09-14 19:00:47Z msweet $"
  *
  * Configuration file for CUPS on Windows.
  *
@@ -96,8 +96,8 @@ typedef unsigned long useconds_t;
  * Version of software...
  */
 
-#define CUPS_SVERSION "CUPS v2.1.0"
-#define CUPS_MINIMAL "CUPS/2.1.0"
+#define CUPS_SVERSION "CUPS v2.2svn"
+#define CUPS_MINIMAL "CUPS/2.2svn"
 
 
 /*
@@ -799,5 +799,5 @@ static __inline int _cups_abs(int i) { return (i < 0 ? -i : i); }
 #endif /* !_CUPS_CONFIG_H_ */
 
 /*
- * End of "$Id: config.h 12831 2015-08-05 14:24:32Z msweet $".
+ * End of "$Id: config.h 12875 2015-09-14 19:00:47Z msweet $".
  */
